@@ -13,7 +13,7 @@
 =========================================================================*/
 #include "gdcmSequenceOfItems.h"
 
-namespace gdcm
+namespace gdcm_ns
 {
 
 void SequenceOfItems::AddItem(Item const &item)
@@ -25,6 +25,14 @@ void SequenceOfItems::AddItem(Item const &item)
     }
 }
 
+Item & SequenceOfItems::AddNewUndefinedLengthItem()
+{
+	Item itemToAdd ;
+	itemToAdd.SetVLToUndefined();
+	this->AddItem( itemToAdd );
+	return GetItem( this->GetNumberOfItems() );
+}
+
 void SequenceOfItems::Clear()
 {
   Items.clear();
@@ -76,4 +84,4 @@ bool SequenceOfItems::FindDataElement(const Tag &t) const
   return found;
 }
 
-} // end namespace gdcm
+} // end namespace gdcm_ns
