@@ -96,8 +96,18 @@ void Bitmap::SetDimensions(const unsigned int *dims)
 {
   assert( NumberOfDimensions );
   //assert( Dimensions.empty() );
+#if 0
   Dimensions = std::vector<unsigned int>(dims,
     dims+NumberOfDimensions);
+#else
+  assert( Dimensions.size() == 3 );
+  Dimensions[0] = dims[0];
+  Dimensions[1] = dims[1];
+  if( NumberOfDimensions == 2 )
+    Dimensions[2] = 1;
+  else
+    Dimensions[2] = dims[2];
+#endif
 }
 
 void Bitmap::SetDimension(unsigned int idx, unsigned int dim)
@@ -208,7 +218,7 @@ bool Bitmap::GetBuffer(char *buffer) const
     // contains a compressed Icon Sequence, one has to guess this is lossless jpeg...
 #ifdef MDEBUG
     const SequenceOfFragments *sqf = PixelData.GetSequenceOfFragments();
-    std::ofstream os( "/tmp/kodak.ljpeg");
+    std::ofstream os( "/tmp/kodak.ljpeg", std::ios::binary);
     sqf->WriteBuffer( os );
 #endif
     gdcmWarningMacro( "Compressed Icon are not support for now" );
@@ -349,7 +359,7 @@ bool Bitmap::TryRAWCodec(char *buffer, bool &lossyflag) const
 #if 0
     if ( GetPixelFormat() != codec.GetPixelFormat() )
       {
-      gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+      Bitmap *i = (Bitmap*)this;
       i->SetPixelFormat( codec.GetPixelFormat() );
       }
 #endif
@@ -378,7 +388,7 @@ bool Bitmap::TryJPEGCodec(char *buffer, bool &lossyflag) const
       if( !sf ) return false;
       const Fragment &frag = sf->GetFragment(0);
       const ByteValue &bv2 = dynamic_cast<const ByteValue&>(frag.GetValue());
-      gdcm::PixelFormat pf = GetPixelFormat(); // gdcm::PixelFormat::UINT8;
+      PixelFormat pf = GetPixelFormat(); // PixelFormat::UINT8;
       codec.SetPixelFormat( pf );
 
       std::stringstream ss;
@@ -392,10 +402,16 @@ bool Bitmap::TryJPEGCodec(char *buffer, bool &lossyflag) const
 #if 0
       if( codec.GetPixelFormat() != GetPixelFormat() )
         {
-        gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+        Bitmap *i = (Bitmap*)this;
         i->SetPixelFormat( codec.GetPixelFormat() );
         }
 #endif
+      if( GetDimensions()[0] != codec.GetDimensions()[0]
+      || GetDimensions()[1] != codec.GetDimensions()[1] )
+{
+      gdcmWarningMacro( "dimension mismatch for JPEG" );
+	((Bitmap*)this)->SetDimensions( codec.GetDimensions() ); //JPEGNote_bogus.dcm
+}
 
       return true;
       }
@@ -422,7 +438,7 @@ bool Bitmap::TryJPEGCodec(char *buffer, bool &lossyflag) const
     // Did PI change or not ?
     if ( GetPlanarConfiguration() != codec.GetPlanarConfiguration() )
       {
-      gdcm::Bitmap *i = (gdcm::Bitmap*)this; (void)i;
+      Bitmap *i = (Bitmap*)this; (void)i;
       //i->SetPlanarConfiguration( codec.GetPlanarConfiguration() );
       }
     // I cannot re-activate the following since I would loose the palette color information
@@ -431,7 +447,7 @@ bool Bitmap::TryJPEGCodec(char *buffer, bool &lossyflag) const
     //  {
     //  // HACK
     //  // YBRisGray.dcm
-    //  gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+    //  Bitmap *i = (Bitmap*)this;
     //  i->SetPhotometricInterpretation( codec.GetPhotometricInterpretation() );
     //  }
 #if 1
@@ -443,14 +459,14 @@ bool Bitmap::TryJPEGCodec(char *buffer, bool &lossyflag) const
 //      assert( GetPixelFormat().GetBitsStored() ==
 //        codec.GetPixelFormat().GetBitsStored() );
       assert( GetPixelFormat().GetBitsAllocated() == 12 );
-      gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+      Bitmap *i = (Bitmap*)this;
       i->SetPixelFormat( codec.GetPixelFormat() );
       }
 #endif
     //if ( GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL_422
     //|| GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL )
     //  {
-    //  gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+    //  Bitmap *i = (Bitmap*)this;
     //  i->SetPhotometricInterpretation( PhotometricInterpretation::RGB );
     //  }
     const ByteValue *outbv = out.GetByteValue();
@@ -458,6 +474,11 @@ bool Bitmap::TryJPEGCodec(char *buffer, bool &lossyflag) const
     unsigned long check = outbv->GetLength();  // FIXME
     (void)check;
     // DermaColorLossLess.dcm has a len of 63531, but DICOM will give us: 63532 ...
+    if( len > outbv->GetLength() )
+      {
+      gdcmErrorMacro( "Impossible length: " << len << " should be (max): " << outbv->GetLength() );
+      return false;
+      }
     assert( len <= outbv->GetLength() );
     if(buffer) memcpy(buffer, outbv->GetPointer(), len /*outbv->GetLength()*/ );  // FIXME
 
@@ -494,7 +515,7 @@ bool Bitmap::TryJPEGCodec2(std::ostream &os) const
     if ( GetPhotometricInterpretation() != codec.GetPhotometricInterpretation() )
       {
       // HACK
-      //gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+      //Bitmap *i = (Bitmap*)this;
       //i->SetPhotometricInterpretation( codec.GetPhotometricInterpretation() );
       }
     const ByteValue *outbv = out.GetByteValue();
@@ -529,10 +550,11 @@ bool Bitmap::TryPVRGCodec(char *buffer, bool &lossyflag) const
     DataElement out;
     bool r = codec.Decode(PixelData, out);
     if(!r) return false;
+    codec.SetLossyFlag( ts.IsLossy() );
     assert( r );
     if ( GetPlanarConfiguration() != codec.GetPlanarConfiguration() )
       {
-      gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+      Bitmap *i = (Bitmap*)this;
       i->PlanarConfiguration = codec.GetPlanarConfiguration();
       }
     const ByteValue *outbv = out.GetByteValue();
@@ -617,7 +639,7 @@ bool Bitmap::TryJPEGLSCodec(char *buffer, bool &lossyflag) const
 // therefore -rightfully- declared as 16 bits...
       if( codec.GetPixelFormat() != GetPixelFormat() )
         {
-        gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+        Bitmap *i = (Bitmap*)this;
         i->SetPixelFormat( codec.GetPixelFormat() );
         }
 #endif
@@ -709,7 +731,7 @@ bool Bitmap::TryJPEG2000Codec(char *buffer, bool &lossyflag) const
         {
         // Because J2K support the full spectrum I do not see any issue
         // with the following:
-        gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+        Bitmap *i = (Bitmap*)this;
         i->SetPixelFormat( codec.GetPixelFormat() );
         }
 #else
@@ -725,13 +747,20 @@ bool Bitmap::TryJPEG2000Codec(char *buffer, bool &lossyflag) const
             {
             if( cpf.GetBitsStored() < pf.GetBitsStored() )
               {
-              gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+              Bitmap *i = (Bitmap*)this;
               gdcmWarningMacro( "Encapsulated stream has fewer bits actually stored on disk. correcting." );
               i->GetPixelFormat().SetBitsStored( cpf.GetBitsStored() );
               }
             }
           }
         }
+      else
+        {
+        // SC16BitsAllocated_8BitsStoredJ2K.dcm
+        gdcmWarningMacro( "Bits Allocated are different. This is pretty bad using info from codestream" );
+        Bitmap *i = (Bitmap*)this;
+        i->SetPixelFormat( codec.GetPixelFormat() );
+        }
 #endif
 
       return true;
@@ -769,7 +798,7 @@ bool Bitmap::TryJPEG2000Codec(char *buffer, bool &lossyflag) const
 #if 0
     if( codec.GetPixelFormat() != GetPixelFormat() )
       {
-      gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+      Bitmap *i = (Bitmap*)this;
       i->SetPixelFormat( codec.GetPixelFormat() );
       }
 #else
@@ -785,7 +814,7 @@ bool Bitmap::TryJPEG2000Codec(char *buffer, bool &lossyflag) const
             {
             if( cpf.GetBitsStored() < pf.GetBitsStored() )
               {
-              gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+              Bitmap *i = (Bitmap*)this;
               gdcmWarningMacro( "Encapsulated stream has fewer bits actually stored on disk. correcting." );
               i->GetPixelFormat().SetBitsStored( cpf.GetBitsStored() );
               }
