@@ -83,7 +83,7 @@ typedef enum {
   CDEF = 0x63646566,
   CMAP = 0x636D6170,
   PCLR = 0x70636c72,
-  RES  = 0x72657320,
+  RES  = 0x72657320
 } OtherType;
 
 static inline bool hasnolength( uint_fast16_t marker )
