@@ -41,14 +41,14 @@ void AAssociateACPDU::SetCalledAETitle(const char calledaetitle[16])
 {
   //size_t len = strlen( calledaetitle );
   //assert( len <= 16 ); // since forwared from AA-RQ no reason to be invalid
-  strncpy(Reserved11_26, calledaetitle, 16 );
+  memcpy(Reserved11_26, calledaetitle, 16 );
 }
 
 void AAssociateACPDU::SetCallingAETitle(const char callingaetitle[16])
 {
   //size_t len = strlen( callingaetitle );
   //assert( len <= 16 ); // since forwared from AA-RQ no reason to be invalid
-  strncpy(Reserved27_42, callingaetitle, 16 );
+  memcpy(Reserved27_42, callingaetitle, 16 );
 }
 
 std::istream &AAssociateACPDU::Read(std::istream &is)
@@ -194,7 +194,7 @@ void AAssociateACPDU::Print(std::ostream &os) const
   os << "Reserved9_10: " << std::hex << Reserved9_10 << std::dec << std::endl;
   os << "Reserved11_26: [" << std::string(Reserved11_26,sizeof(Reserved11_26)) << "]" << std::endl;
   os << "Reserved27_42: [" << std::string(Reserved27_42,sizeof(Reserved27_42)) << "]" << std::endl;
-  os << "Reserved43_74: [" << std::string(Reserved43_74,sizeof(Reserved43_74)) << "]" << std::endl;
+  /*os << "Reserved43_74: [" << std::string(Reserved43_74,sizeof(Reserved43_74)) << "]" << std::endl;*/
   os << "Application Context Name: ";
   AppContext.Print( os );
   os << "List of PresentationContextAC: " << std::endl;
