@@ -197,7 +197,8 @@ bool AAssociateRQPDU::IsAETitleValid(const char title[16])
     }
   if( str != s ) return false;
 #else
-  std::string s ( title, 16 );
+  const size_t reallen = strlen( title );
+  std::string s ( title, std::min(reallen, (size_t)16) );
   // check no \0 :
   size_t len = strlen( s.c_str() );
 
@@ -225,7 +226,7 @@ void AAssociateRQPDU::SetCalledAETitle(const char calledaetitle[16])
   if( len <= 16 )
     {
     memset(CalledAETitle, ' ', sizeof(CalledAETitle));
-    strncpy(CalledAETitle, calledaetitle, len );
+    memcpy(CalledAETitle, calledaetitle, len );
     }
   // FIXME Need to check upper case
   // FIXME cannot set to only whitespaces
@@ -238,7 +239,7 @@ void AAssociateRQPDU::SetCallingAETitle(const char callingaetitle[16])
   if( len <= 16 )
     {
     memset(CallingAETitle, ' ', sizeof(CallingAETitle));
-    strncpy(CallingAETitle, callingaetitle, len );
+    memcpy(CallingAETitle, callingaetitle, len );
     }
   // FIXME Need to check upper case
   // FIXME cannot set to only whitespaces
