@@ -59,7 +59,7 @@ ServiceClassUser::ServiceClassUser()
   Internals->hostname = "localhost";
   Internals->port = 104;
   Internals->portscp = 104;
-  Internals->aetitle = "GDCMSCU";
+  Internals->aetitle = GDCM_AETITLE;
   Internals->calledaetitle = "ANY-SCP";
   Internals->timeout = 10;
 }
@@ -71,7 +71,10 @@ ServiceClassUser::~ServiceClassUser()
 
 void ServiceClassUser::SetPresentationContexts(std::vector<PresentationContext> const & pcs)
 {
-  Internals->mConnection->SetPresentationContexts(pcs);
+  if( Internals->mConnection )
+    {
+    Internals->mConnection->SetPresentationContexts(pcs);
+    }
 }
 
 bool ServiceClassUser::IsPresentationContextAccepted(const PresentationContext& pc) const
@@ -346,10 +349,18 @@ bool ServiceClassUser::SendFind(const BaseRootQuery* query, std::vector<DataSet>
   case 0xA900: // Identifier Does Not Match SOP Class
       {
       Attribute<0x0,0x0901> errormsg;
-      errormsg.SetFromDataSet( ds );
-      gdcm::Tag const & t = errormsg.GetValue();
-      gdcmErrorMacro( "Offending Element: " << t ); (void)t;
+      if( ds.FindDataElement( errormsg.GetTag() ) )
+        {
+        errormsg.SetFromDataSet( ds );
+        gdcm::Tag const & t = errormsg.GetValue();
+        gdcmErrorMacro( "Offending Element: " << t ); (void)t;
+        }
+      else
+        {
+        gdcmErrorMacro( "Offending Element ??" );
+        }
       }
+    break;
   case 0xA700: // Refused: Out of Resources
       {
       Attribute<0x0,0x0902> errormsg;
@@ -796,7 +807,7 @@ EStateID ServiceClassUser::RunMoveEventLoop(ULEvent& currentEvent, ULConnectionC
         }
       catch ( std::exception & e )
         {
-        gdcmErrorMacro( "Error 2nd connection:" << e.what() );
+        gdcmErrorMacro( "Error 2nd connection:" << e.what() ); (void)e;
         }
       catch ( ... )
         {
