@@ -238,6 +238,7 @@ static const char * const printmd5[][2] = {
 { "807bf2aef3bc1885217c8a12d2d2bc19" , "JPEGNote_bogus.dcm" },
 { "669cc0e807673ebe57124739a1874f35" , "RLEDebianBug816607Orig.dcm" },
 { "1daa9bb53a8ce090041472f528248686" , "IllegalGroup2ImplicitTS.dcm" },
+{ "49542e6002129f42f86f25e840b6beed" , "GE_MR_0025xx1bProtocolDataBlockXML.dcm" },
 
 
 { 0 ,0 }
@@ -272,6 +273,7 @@ int TestPrint(const char *filename, bool verbose= false)
       && strcmp(name, "SIEMENS_GBS_III-16-ACR_NEMA_1.acr" ) != 0
       && strcmp(name, "LIBIDO-24-ACR_NEMA-Rectangle.dcm" ) != 0
       && strcmp(name, "NM_Kakadu44_SOTmarkerincons.dcm" ) != 0
+      && strcmp(name, "GE_MR_0025xx1bProtocolDataBlockXML.dcm" ) != 0
     )
       {
       std::cerr << "UNKNOWN Attribute with : " << name << std::endl;
