@@ -89,11 +89,9 @@ class vtkAngleWidget;
 #include <getopt.h>
 #include <assert.h>
 
-#if VTK_MAJOR_VERSION >= 6
 #ifndef vtkFloatingPointType
 #define vtkFloatingPointType double
 #endif
-#endif
 
 //----------------------------------------------------------------------------
 // vtkImageViewer2 new interface wants SetSlice, but vtkImageViewer does not have
@@ -102,11 +100,7 @@ class vtkAngleWidget;
 class vtkGDCMImageViewer : public vtkImageViewer
 {
 public:
-#if VTK_MAJOR_VERSION < 6
-  vtkTypeRevisionMacro(vtkGDCMImageViewer,vtkImageViewer);
-#else
   vtkTypeMacro(vtkGDCMImageViewer,vtkImageViewer);
-#endif
 
   static vtkGDCMImageViewer *New()
     {
@@ -129,11 +123,7 @@ public:
   double GetOverlayVisibility() { return 0; }
   void SetOverlayVisibility(double vis) {(void)vis;}
 };
-#if VTK_MAJOR_VERSION < 6
-vtkCxxRevisionMacro(vtkGDCMImageViewer, "$Revision: 1.30 $")
-#else
 //vtkCxxRevisionMacro(vtkGDCMImageViewer, "$Revision: 1.30 $")
-#endif
 vtkInstantiatorNewMacro(vtkGDCMImageViewer)
 
 #if VTK_MAJOR_VERSION >= 5
@@ -141,11 +131,7 @@ vtkInstantiatorNewMacro(vtkGDCMImageViewer)
 class vtkImageColorViewer : public vtkImageViewer2
 {
 public:
-#if VTK_MAJOR_VERSION < 6
-  vtkTypeRevisionMacro(vtkImageColorViewer,vtkImageViewer2);
-#else
   vtkTypeMacro(vtkImageColorViewer,vtkImageViewer2);
-#endif
 
   static vtkImageColorViewer *New()
     {
@@ -183,11 +169,7 @@ public:
 private:
   vtkImageActor                   *OverlayImageActor;
 };
-#if VTK_MAJOR_VERSION < 6
-vtkCxxRevisionMacro(vtkImageColorViewer, "$Revision: 1.30 $")
-#else
 //vtkCxxRevisionMacro(vtkImageColorViewer, "$Revision: 1.30 $")
-#endif
 vtkInstantiatorNewMacro(vtkImageColorViewer)
 #endif
 
