@@ -26,12 +26,8 @@
 #include "gdcmFilenameGenerator.h"
 
 #ifndef vtkFloatingPointType
-#if VTK_MAJOR_VERSION < 6
-#define vtkFloatingPointType float
-#else
 #define vtkFloatingPointType double
 #endif
-#endif
 /*
  * Test to show the pipeline for
  * IPPSorter -> vtkGDCMImageReader -> vtkImageChangeInformation
