@@ -47,11 +47,7 @@
 
 #include <limits>
 
-#if VTK_MAJOR_VERSION < 6
-vtkCxxRevisionMacro(vtkGDCMImageWriter, "$Revision: 1.1 $")
-#else
 //vtkCxxRevisionMacro(vtkGDCMImageWriter, "$Revision: 1.1 $")
-#endif
 vtkStandardNewMacro(vtkGDCMImageWriter)
 
 //vtkCxxSetObjectMacro(vtkGDCMImageWriter,LookupTable,vtkLookupTable)
@@ -70,12 +66,8 @@ inline bool vtkGDCMImageWriter_IsCharTypeSigned()
 }
 
 #ifndef vtkFloatingPointType
-#if VTK_MAJOR_VERSION < 6
-#define vtkFloatingPointType float
-#else
 #define vtkFloatingPointType double
 #endif
-#endif
 
 //----------------------------------------------------------------------------
 vtkGDCMImageWriter::vtkGDCMImageWriter()
