@@ -17,14 +17,13 @@
 /* Use the charls library configured for gdcm.  */
 #include "gdcmTypes.h"
 #ifdef GDCM_USE_SYSTEM_CHARLS
-// It is expected that 1.0 API is used (JlsParameters instead of JlsParamaters)
+// It is expected that version 1.1.0 is used
 # include <CharLS/header.h>
 # include <CharLS/interface.h>
 # include <CharLS/util.h>
 # include <CharLS/defaulttraits.h>
 # include <CharLS/losslesstraits.h>
 # include <CharLS/colortransform.h>
-//# include <CharLS/streams.h>
 # include <CharLS/processline.h>
 #else
 #include "gdcmcharls/header.h"
@@ -33,7 +32,6 @@
 #include "gdcmcharls/defaulttraits.h"
 #include "gdcmcharls/losslesstraits.h"
 #include "gdcmcharls/colortransform.h"
-#include "gdcmcharls/streams.h"
 #include "gdcmcharls/processline.h"
 #endif
 
